@@ -1,7 +1,5 @@
-use std::io;
-
 fn main() {
-    let stdin = io::stdin();
+    let stdin = std::io::stdin();
     let mut args: Vec<String> = std::env::args().collect();
     args.remove(0);
 
